You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@accumulo.apache.org by ec...@apache.org on 2013/11/26 16:18:31 UTC

[36/37] git commit: ACCUMULO-645: found more references to HADOOP_HOME

ACCUMULO-645: found more references to HADOOP_HOME

git-svn-id: https://svn.apache.org/repos/asf/accumulo/trunk@1431596 13f79535-47bb-0310-9956-ffa450edef68
(cherry picked from commit 02829fffc3ad9261648da5dd12a02dfcafa5a0fa)

Reason: Hadoop2 compat
Author: Eric C. Newton <ec...@apache.org>
Ref: ACCUMULO-1792

Signed-off-by: Eric Newton <er...@gmail.com>


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/d70e5a12
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/d70e5a12
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/d70e5a12

Branch: refs/heads/1.4.5-SNAPSHOT
Commit: d70e5a12739a7775995340be3dca5d460cdf7be2
Parents: 344e725
Author: Eric C. Newton <ec...@apache.org>
Authored: Thu Jan 10 20:10:42 2013 +0000
Committer: Eric Newton <er...@gmail.com>
Committed: Mon Nov 25 16:06:44 2013 -0500

----------------------------------------------------------------------
 bin/tool.sh | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/d70e5a12/bin/tool.sh
----------------------------------------------------------------------
diff --git a/bin/tool.sh b/bin/tool.sh
index 3c114e8..cefd6b9 100755
--- a/bin/tool.sh
+++ b/bin/tool.sh
@@ -20,8 +20,8 @@ bin=`dirname "$0"`
 bin=`cd "$bin"; pwd`
 . "$bin"/config.sh
 
-if [ -z $HADOOP_HOME ] ; then
-    echo "HADOOP_HOME is not set.  Please make sure it's set globally or in conf/accumulo-env.sh"
+if [ -z $HADOOP_PREFIX ] ; then
+    echo "HADOOP_PREFIX is not set.  Please make sure it's set globally or in conf/accumulo-env.sh"
     exit 1
 fi
 if [ -z $ZOOKEEPER_HOME ] ; then
@@ -98,5 +98,5 @@ fi
 #echo USERJARS=$USERJARS
 #echo CLASSNAME=$CLASSNAME
 #echo HADOOP_CLASSPATH=$HADOOP_CLASSPATH
-#echo exec "$HADOOP_HOME/bin/hadoop" jar "$TOOLJAR" $CLASSNAME -libjars \"$LIB_JARS\" $ARGS
-exec "$HADOOP_HOME/bin/hadoop" jar "$TOOLJAR" $CLASSNAME -libjars \"$LIB_JARS\" "$@"
+#echo exec "$HADOOP_PREFIX/bin/hadoop" jar "$TOOLJAR" $CLASSNAME -libjars \"$LIB_JARS\" $ARGS
+exec "$HADOOP_PREFIX/bin/hadoop" jar "$TOOLJAR" $CLASSNAME -libjars \"$LIB_JARS\" "$@"